#
# spec file for package libnl3
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libnl3
%define lname	libnl3-200
%define with_tools 1
%define uver	3_11_0
Version:        3.11.0
Release:        1.4
Summary:        Convenience library for working with Netlink sockets
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            http://www.carisma.slowglass.com/~tgr/libnl/#(outdated)

#Git-Clone:	https://github.com/thom311/libnl/
Source:         https://github.com/thom311/libnl/releases/download/libnl%uver/libnl-%version.tar.gz
Source2:        https://github.com/thom311/libnl/releases/download/libnl%uver/libnl-%version.tar.gz.sig
# https://tynq.net/49EA7C670E0850E7419514F629C2366E4DFC5728.gpg
Source3:        %name.keyring
Source9:        baselibs.conf
BuildRequires:  bison >= 2.4
BuildRequires:  fdupes
BuildRequires:  flex >= 2.5.19

%description
The libnl suite is a collection of libraries providing APIs to
Netlink protocol based Linux kernel interfaces.

%package -n %lname
Summary:        Convenience library for working with Netlink sockets
License:        LGPL-2.1-only
Group:          System/Libraries
Requires:       libnl-config >= %version

%description -n %lname
The libnl suite is a collection of libraries providing APIs to
netlink protocol based Linux kernel interfaces.

%package devel
Summary:        Libraries and headers for libnl
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Provides:       libnl-devel = %version-%release
# Starting with libnl3(-3.2), no more conflicts

%description devel
The libnl suite is a collection of libraries providing APIs to
Netlink protocol based Linux kernel interfaces.

%if %with_tools
#
# Only one of the libnl packages should create the config and tools.
#

%package -n libnl-config
Summary:        Name maps for libnl
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Productivity/Networking/Security
%if 0%{?suse_version} >= 1130
BuildArch:      noarch
%endif

%description -n libnl-config
This package contains configuration files for libnl and programs using
the same; in particular
- name maps for class-ids -- class-names (like /etc/services)
- aliases for locations within a packet (ip6.dst => byte offset)

%package -n libnl-tools
Summary:        Command line utilities to directly work with Netlink
License:        GPL-2.0-only
Group:          Productivity/Networking/Security

%description -n libnl-tools
Various test program with which the functionality of libnl is
demonstrated.

%endif

%prep
%autosetup -p0 -n libnl-%version

%build
%configure --disable-static
%make_build pkglibdir="%_libdir/%lname"

%install
b="%buildroot"
%make_install pkglibdir="%_libdir/%lname"
find "$b" -iname "*.la" -delete
%if !%with_tools
rm -Rf "$b/%_sysconfdir/libnl"
rm -Rf "$b/%_sbindir" "$b/%_mandir/man8"
%endif
%if 0%{?fdupes:1}
%fdupes %buildroot/%_prefix
%endif

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libnl*.so.200*
%_libdir/%lname

%files devel
%_includedir/%name
%_libdir/libnl*.so
%_libdir/pkgconfig/*

%if %with_tools

%files -n libnl-config
%dir %_sysconfdir/libnl
%config %_sysconfdir/libnl/*

%files -n libnl-tools
%_mandir/man*/*
%_bindir/*
%endif

%changelog
* Wed Oct 30 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.11
  * Add NLA_{SINT|UINT} attribute types
  * Add NLA functions for variable-length integers
  * link/bonding: add getters for attributes
  * lib/route: add support for bridge msti
* Sat Jul 20 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.10
  * route: support for setting ageing time for dynamic bridge
    table entries
  * route: support for VLAN filtering on bridge ports
  * route: support for layer 3 filtering on bridges
* Mon Dec  4 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.9
  * route/link: add bonding interface options set rtnl apis
  * route: fix memleak in rtnl_act_parse()
  * route/tc: avoid integer overflow in rtnl_tc_calc_cell_log()
* Tue Aug 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8
  * addr: create an all-zero addresses when parsing "any" or "default"
  * addr: allow constructing all-zero addresses
  * route: construct all-zero addresses for default route destination
  * bridge: Add support for link_info of a bridge
  * bridge: extend libnl with options needed for VLAN aware forwarding
  * route/link: add accessor API for IPv6 DEVCONF
  * neigh: add support of NHID attribute
  * route: add nh type
* Wed Jul  6 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.7
  * route/mdb: fix buffer overflow in mdb_msg_parser()
  * route/act: add NAT action
* Fri Apr 15 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.6.0
  * route/mdb: add support for MAC multicast entries
  * mdb: support bridge multicast database notification
  * Support Hardware offload capability for MACsec
  * nflog: add CT support
  * Add IPv6 GRE support
  * Add IPv6 VTI support
  * Add support for team devices
- Drop 0001-route-link-add-RTNL_LINK_REASM_OVERLAPS-stat.patch
  (merged)
* Mon Aug 23 2021 Jan Engelhardt <jengelh@inai.de>
- Add 0001-route-link-add-RTNL_LINK_REASM_OVERLAPS-stat.patch
  [boo#1189451]
* Wed Oct 14 2020 Jan Engelhardt <jengelh@inai.de>
- Modernize specfile constructs.
* Thu Dec 19 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.5.0
  * route/qdisc: add 64-bit rate/ceil support for htb class
  * xfrmi: introduce XFRM interfaces support
  * xfrm: fix memory corruption (dangling pointer) when when
    setting xfrmnl_sa
  * route/link: avoid dangling pointer in rtnl_link_set_slave_type()
  * nla_ok: fix overrun in attribute iteration.
  * route:act: add vlan action
  * route:tc: allow to set chain index for tc objects
  * route:qdisc: add MQPRIO Qdisc
  * if_tunnel: update IFLA defines up to FWMARK
  * Add support for cloning cgroup filter objects
  * neigh: cache updates as well query AF_BRIDGE neigh
  * route:cls: add matchall classifier
  * neigh: support bridge entries for vxlan interfaces
  * rule: add support for protocol and port ranges
  * link: add Geneve support
* Mon Feb 26 2018 jengelh@inai.de
- Update to new upstream release 3.4.0 [boo#1082756]
  * route/link: add accessor API for IPv6 flags
  * Provide accessors for actions (rtnl_act).
  * rule: Add support for l3mdev in FIB rules
  * addr: add AF_VSOCK to translation table
  * addr: Add support for AF_MPLS
  * route: Add support for MPLS address family
  * route: Add support for TTL propagation in MPLS routes
  * route: Add support for lwtunnel and MPLS  encapsulations
* Wed Jun  7 2017 jengelh@inai.de
- Update to final release 3.3.0
  * No changes
* Fri Mar 17 2017 jengelh@inai.de
- Update to new upstream release 3.3.0~rc1
  * sriov: fix crash in rtnl_link_sriov_parse_vflist
  * sriov: avoid buffer overrun in rtnl_link_sriov_parse_vflist()
  * use O_CLOEXEC
  * lib/attr.c: check for valid length argument in nla_reserve()
  * route: neigh: use NDA_MASTER for neigh->n_master if available
  * xfrm: allow quering optional arguments from xfrmnl_sp_get_sec_ctx()
- Drop nla-reverse.diff (included upstream)
* Wed Jan 18 2017 jengelh@inai.de
- Add nla-reserve.diff [boo#1020123]
* Mon Jan 16 2017 jengelh@inai.de
- Update to new upstream release 3.2.29
  * nl-addr: avoid read-out-of-bound in nl_addr_fill_sockaddr()
  * lib: add utility function nl_strerror_l()
  * lib/route: allow override of message type during link change
  * lib/route: set IFLA_PROTINFO attribute in request message
  * lib/route: Add port state translation functions
  * lib/route: Extend Bridge Flags
  * lib/route: Allow override of IFLA_AF_SPEC nesting
  * lib/route: Support IFLA_BRIDGE_MODE
  * macvlan: add support for "source" mode
  * macvlan: adjust types and merge MACVLAN_HAS_MACCOUNT and
  MACVLAN_HAS_MACDATA
  * vxlan: add support for additional VXLAN attributes
  * lib/route: SRIOV Parse, Read, Clone support
  * Add PPP support
  * route/act: add gact tc action
  * link: add support for IFLA_CARRIER_CHANGES, IFLA_PHYS_PORT_NAME,
  IFLA_PHYS_SWITCH_ID, IFLA_GSO_MAX_SEGS and IFLA_GSO_MAX_SIZE
* Wed Aug 10 2016 jengelh@inai.de
- Update to new upstream release 3.2.28
  * route/link: IFLA_VLAN_PROTOCOL added to vlan_put_attrs
  * route/vrf: add VRF support
  * route/link: add macvtap support
  * sit: add 6RD support
  * lib/route: add macsec support
* Tue Feb  2 2016 jengelh@inai.de
- Update to new upstream release 3.2.27
  * link: add ifb device support
  * qdisc: add hfsc qdisc support
  * route/act: add skbedit action
  * New sublibraries: libnl-xfrm-3.0
* Wed Oct  8 2014 olaf@aepfle.de
- BuildRequire at least bison 2.4, version in SLE11 is too old
* Wed Jul 16 2014 jengelh@inai.de
- Update to new upstream release 3.2.25
  * route: fix off-by-one in rtnl_act_parse()
  * act: fix policy range check
  * act: fix the logic of parsing actions
  * u32: prevent memcpy from NULL
  * attr: prevent garbage return value for NULL param
  * introduce ipip, ip6, gre, sit tunnel support
  * tc: add co_groups for tc qdisc and filter
* Fri Apr 25 2014 dmueller@suse.com
- remove python-devel dependency
* Sun Mar  9 2014 jengelh@inai.de
- Update to new upstream release 3.2.24
  * Add support for: ingress qdiscs, veth links, link network
  namespaces, tc action (general), mirred tc action, u32 tc action,
  fq_codel qdisc
* Tue Nov 26 2013 jengelh@inai.de
- Update to new upstream release 3.2.23
  * Add macvlan and VXVLAN support
* Wed Jun  5 2013 jengelh@inai.de
- Update to new upstream release 3.2.22
  * ct: add ICMPv6 type,code and ID
  * attr: Provide nla_is_nested() function
  * bridge: Support the new bridging attributes
  * bridge: Provide rtnl_link_bridge_alloc()
  * vlan: Provide rtnl_link_vlan_alloc()
  * bond: Provide rtnl_link_bond_alloc()
  * attr: Add nla_nest_cancel() to remove partially added nested
  attributes
- Remove 0001-Add-symbol-version-maps-to-libnl.patch
  (merged upstream)
* Thu Mar  7 2013 jengelh@inai.de
- Add preliminary symbol versioning for libnl
  (0001-Add-symbol-version-maps-to-libnl.patch)
* Fri Jan 25 2013 jengelh@inai.de
- Update to new upstream release 3.2.21
  * SocketCAN support
  * Add link carrier support
* Sun Nov 25 2012 jengelh@inai.de
- Update to new upstream release 3.2.16
  * Optional hashtable backend for caches
  * Improved netlink expectations support
  * Extended AF_BRIDGE support for link and neighbour caches
  * Better thread safety in module registration operations
* Wed Nov 14 2012 jengelh@inai.de
- Update to new upstream release 3.2.14
  * This release contains bugfixes and adds support for some new link
  features.
* Tue Oct  9 2012 jengelh@inai.de
- Update to new upstream release 3.2.13
  * More clean NL_AUTO_PORT and NL_AUTO_SEQ usage in nl_complete_msg
  * genl_ctrl_probe_by_name: fix checking of genlmsg_put() return value
* Fri Aug 31 2012 jengelh@inai.de
- Update to new upstream release 3.2.12
  * Add new API to retrieve versioning information at runtime
  suitable for python ctype.
* Tue Jun 19 2012 jengelh@inai.de
- Update to new upstream release 3.2.11
  * add fwmark mask support
  * genl: add genlmsg_hdr(), genlmsg_user_hdr(), genlmsg_user_data(),
  and genlmsg_user_datalen()
  * genl: Export genl_ops_resolve() and genl_mngt_resolve() in header
  * rtnl_link_(get|set)_weight is deprecated in libnl
* Fri May 11 2012 vuntz@opensuse.org
- Update to version 3.2.9:
  * Fix return value of nl_recvmsgs()
* Sat May  5 2012 jengelh@medozas.de
- Update to new upstream release 3.2.8
  * Support plug qdisc - queue traffic until explicit release
* Wed Feb  8 2012 jengelh@medozas.de
- Update to new upstream release 3.2.7
  * link: fix regression in link message parser
  * nl_addr_cmp: handle prefix length during address comparison
  * avoid dangling co_major_cache reference to NL_AUTO_PROVIDE caches
  * dsmark: Add missing declarations for
  rtnl_class_dsmark_(get|set)_bitmask
  * rtnl_link_bond_add: allow to allocate bond name in case NULL
  is given
  * link: allow to add/get linkinfo of unknown type
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Tue Jan  3 2012 adrian@suse.de
- add dangling-co_major_cache-reference fix required by ntrack
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Nov 11 2011 jengelh@medozas.de
- Update to new upstream release 3.2.3
  * Add missing libnl-cli-3.0 pkgconfig file
  * Fix memory leaks durgin rtnl_addr object freeing
* Wed Sep 21 2011 jengelh@medozas.de
- Update to new upstream release 3.2.1
  * new API to create/enslave/release bonding devices
* Tue Sep 20 2011 jengelh@medozas.de
- Relax Requires in libnl3-devel
* Wed Sep 14 2011 jengelh@medozas.de
- Update to libnl-3.2
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Wed Dec 16 2009 jengelh@medozas.de
- Add baselibs.conf as a source
- Add baselib definitions for SPARC
- Enable parallel building
* Fri Jun 12 2009 coolo@novell.com
- fix build with glibc 2.10
* Thu Feb  5 2009 bphilips@suse.de
- baselibs.conf: create -32bit packages. Required to compile Intel
  WiMax tools.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Nov 11 2008 jpr@novell.com
- Add baselibs.conf (bnc#443023)
* Thu Oct  2 2008 maw@suse.de
- Install libraries in %%_lib, not %%{_libdir} (bnc#428433).
* Fri Feb  1 2008 coolo@suse.de
- update to 1.1:
  o patches went upstream
  o Generic netlink support
  o Route Addition/Deletion
  o Fixed reference counting while objects stay in caches.
  ... tons of other fixes
* Fri Jan 25 2008 adrian@suse.de
- fix changelog entries order
* Wed Oct  3 2007 maw@suse.de
- Apply libnl.route.metric-overflow.patch with -p1.
* Sat Aug 25 2007 olh@suse.de
- remove incomplete copies of kernel headers
  linux/types.h were needed
* Fri Aug 24 2007 olh@suse.de
- include linux/types.h
  do not redefine typedefs
  use stddef.h offsetof
  fix out of bounds access in route metric functions
  fix incorrect char usage in nl_str2af
  remove compiler warnings by checking vasprintf return value
* Wed Aug 22 2007 dmueller@suse.de
- fix accesses of free'd memory which crash NetworkManager-kde
* Wed Aug 22 2007 dmueller@suse.de
- update to 1.0-pre6:
  * fixes write after delete crashes
  * fixes realloc() handling
  * fixes format string warnings
  * fixes invalid free in nl_addr_parse for AF_UNSPEC addresses
  * fixes double nlmsg_free() in nl_recvmsgs() while receiving
    a multipart message and the read was interrupted.
* Sun Feb 19 2006 ro@suse.de
- fix build on ia64, ppc64, s390x
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 15 2005 yxu@suse.de
- fixed conflicting type definition
* Fri Nov  4 2005 rml@suse.de
- Update to 1.0-pre5
* Mon Oct 31 2005 gekker@suse.de
- Initial import into autobuild Version 1.0-pre3
- Patch makefile
